==> gsphonebook-0.1.tar.bz2: gsphonebook-0.1/html/index.php <==
<?php
require("index.common.php");

echo '<?xml version="1.0" encoding="UTF-8"?>'
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
	<head>
		<meta http-equiv="content-type" content="application/xhtml+xml; charset=UTF-8" />
		<title><?=_("Asterisk GS Phonebook");?></title> 
		<link rel="stylesheet" type="text/css" href="styles.css">
		<?php $xajax->printJavascript($xajaxdir); ?> 
		<script language="JavaScript">
		/* <![CDATA[ */
			var searchFunc = xajax_pb_search;

			function setSearchType(type) {
				sb = document.getElementById('searchbox');
				sb.value = '';
				switch(type) {
					case 'history':
						sb.disabled = false;
						searchFunc = xajax_history_search;;
						break;
					case 'admin_user':
						sb.disabled = false;
						searchFunc = xajax_ulist_search;
						break;
					case 'admin_group':
						sb.disabled = false;
						searchFunc = xajax_glist_search;
						break;
					case 'off':
						sb.disabled = true;
						break;
					default:
						sb.disabled = false;
						searchFunc = xajax_pb_search;
				}
			}
			function clearSearchbox() {
				sb = document.getElementById('searchbox');
				sb.value = '';
				sb.disabled = false;
			}
			function disableSearchbox() {
				sb = document.getElementById('searchbox');
				sb.value = '';
				sb.disabled = true;
			}

			function get_options(id, type) {
				options = document.getElementById(id).childNodes;
				list = new Array();
				for(i = 0; i < options.length; i++) {
					if((type == 'all') || (options[i].selected))
						list.push(new Array(options[i].value, options[i].innerHTML));
				}
				return list;
			}

			function select_options(id) {
				options = document.getElementById(id).childNodes;
				for(i = 0; i < options.length; i++)
					options[i].selected = true;
			}
		/* ]]> */
		</script>
	</head> 
	<body> 
		<div id='logininfo' class='logininfo'><?=get_logininfo()?></div>
		<h1><?=_("GS/* phonebook")?> v0.1</h1>
		<ul class="menu" id='menu'>
			<li><?=_("Search")?>: <input type="text" name="searchbox" id="searchbox" size="20" onkeyup="searchFunc(document.getElementById('searchbox').value);"/></li>
			<li><a href="#" onclick="setSearchType('phonebook');xajax_pb_search('');return false;"><?=_("Phonebook")?></a></li>
			<!--<li><a href="#" onclick="setSearchType('history');xajax_history_search('');return false;"><?=_("Call history")?></a></li>-->
			<li><a href="#" onclick="setSearchType('off');xajax_up_display('');return false;"><?=_("Preferences")?></a></li>
			<?php if($_SESSION['admin']) { ?>
			<li><a href="#" onclick="setSearchType('off');xajax_admin('');return false;"><?=_("Administration")?></a></li>
			<?php } ?>
			<li><a href="index.php?logout=1"><?=_("Logout")?></a></li>
		</ul>
		<ul class="submenu" id='submenu'></ul>
		<div class="callinfo" id="callinfo"></div>
		<div class="content" id="content">
		<?php
			$pb = new phonebook();
			print $pb->get_list("");
		?>
		</div>
	</body> 
</html>

==> gsphonebook-0.3.tar.bz2: gsphonebook-0.3/html/index.php <==
<?php
require("index.common.php");

echo '<?xml version="1.0" encoding="UTF-8"?>'
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
	<head>
		<meta http-equiv="content-type" content="application/xhtml+xml; charset=UTF-8" />
		<title><?=_("Asterisk GS Phonebook");?></title> 
		<link rel="stylesheet" type="text/css" href="styles.css">
		<?php $xajax->printJavascript($xajaxdir); ?> 
		<script src="functions.js" type="text/javascript"></script>
	</head> 
	<body> 
		<div id='logininfo' class='logininfo'><?=get_logininfo()?></div>
		<h1><?=_("GS/* phonebook")?> v0.3</h1>
		<ul class="menu" id='menu'>
			<!--<li><?=_("Search")?>: <input type="text" name="searchbox" id="searchbox" size="20" onkeyup="searchFunc(document.getElementById('searchbox').value);"/></li>-->
			<li><?=_("Search")?>: <input type="text" name="searchbox" id="searchbox" size="20" onkeyup="OnKeyRequestBuffer.modified('searchbox');"/></li>
			<li><a href="#" onclick="setSearchType('phonebook');xajax_pb_search('');return false;"><?=_("Phonebook")?></a></li>
			<li><a href="#" onclick="setSearchType('history');xajax_history_search('');return false;"><?=_("Call history")?></a></li>
			<li><a href="#" onclick="setSearchType('off');xajax_up_display('');return false;"><?=_("Preferences")?></a></li>
			<?php if($_SESSION['admin']) { ?>
			<li><a href="#" onclick="setSearchType('off');xajax_admin('');return false;"><?=_("Administration")?></a></li>
			<?php } ?>
			<li><a href="index.php?logout=1"><?=_("Logout")?></a></li>
		</ul>
		<ul class="submenu" id='submenu'></ul>
		<div class="callinfo" id="callinfo"></div>
		<div class="content" id="content">
		<?php
			$pb = new phonebook();
			print $pb->get_list("");
		?>
		</div>
	</body> 
</html>
